# SatNOGS Network

SatNOGS Network is a web application, implementing a global scheduling and monitoring network for ground station operations.

It features multiple observers to multiple intrumentation functionality and manages observation jobs and results.

## Contribute

Check out the [documentation](https://docs.satnogs.org/projects/satnogs-network/en/stable/) on how to setup a local development instance.

The main repository lives on [Gitlab](https://gitlab.com/librespacefoundation/satnogs/satnogs-network) and all Merge Request should happen there.

## Join

[![irc](https://img.shields.io/badge/Matrix-%23satnogs:matrix.org-blue.svg)](https://riot.im/app/#/room/#satnogs:matrix.org)
[![irc](https://img.shields.io/badge/IRC-%23satnogs%20on%20freenode-blue.svg)](https://webchat.freenode.net/?channels=satnogs)
[![irc](https://img.shields.io/badge/forum-discourse-blue.svg)](https://community.libre.space/c/satnogs)

## Current Development

[![kanban](https://img.shields.io/badge/kanban-board-lightgray.svg)](https://gitlab.com/librespacefoundation/satnogs/satnogs-network/boards/345495)
[![build](https://gitlab.com/librespacefoundation/satnogs/satnogs-network/badges/dev/build.svg)](https://gitlab.com/librespacefoundation/satnogs/satnogs-network/commits/dev)
[![coverage](https://gitlab.com/librespacefoundation/satnogs/satnogs-network/badges/dev/coverage.svg)](https://gitlab.com/librespacefoundation/satnogs/satnogs-network/commits/dev)

## License

[![license](https://img.shields.io/badge/license-AGPL%203.0-6672D8.svg)](LICENSE)
[![Libre Space Foundation](https://img.shields.io/badge/%C2%A9%202014--2018-Libre%20Space%20Foundation-6672D8.svg)](https://librespacefoundation.org/)
